@@ -2,27 +2,40 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from collections import ChainMap
-from collections.abc import Mapping
+from collections.abc import MutableMapping
 from functools import lru_cache
 from pathlib import Path
 from time import time
-from typing import Any, AnyStr, Dict, Hashable, NoReturn, Optional, Tuple, Union
+from typing import (
+    Any, AnyStr, Dict, Hashable,
+    Optional, TYPE_CHECKING, Tuple, Union
+)
+
+if TYPE_CHECKING:
+    from ConfigFramework.custom_types import key_type, defaults_type, data_type
 
 
-class AbstractConfigLoader(ABC, Mapping):
+class AbstractConfigLoader(ABC, MutableMapping):
     """
     Base class for any of your loaders. Initialization can be made through load function, or, if author wants so,
     through `__init__` function.
     """
+    lookup_data: Union[
+        ChainMap,
+        MutableMapping[Hashable, Any],
+        Dict[Hashable, Any]
+    ]
 
     def __init__(
-        self, data: Union[Dict, ChainMap, Mapping], defaults: Dict, include_defaults_to_dumps: Optional[bool] = None,
+        self, data: data_type,
+        defaults: defaults_type,
+        include_defaults_to_dumps: bool = False,
         *args, **kwargs
     ):
         """
         Creates new config first_loader with your variables.
 
-        :param data: data from first_loader.
+        :param data: data from loader.
         :param defaults: default variables that will be used if not found in first_loader.
         :param include_defaults_to_dumps: represents if default values should be dumped to that first_loader.
         :param args: arguments that can be used for your custom loaders.
@@ -31,7 +44,7 @@ class AbstractConfigLoader(ABC, Mapping):
         self.__created_at = str(time())
         self.data = data
         self.include_defaults: bool = include_defaults_to_dumps
-        self.defaults = defaults
+        self.defaults: Dict[key_type, Any] = defaults or {}
 
         if isinstance(defaults, dict):
             self.lookup_data = ChainMap(self.data, self.defaults)
@@ -52,7 +65,7 @@ class AbstractConfigLoader(ABC, Mapping):
         pass
 
     @abstractmethod
-    def dump(self, include_defaults: bool = False) -> NoReturn:
+    def dump(self, include_defaults: bool = False) -> None:
         """
         Dumps updated variables to loader.
 
@@ -61,7 +74,7 @@ class AbstractConfigLoader(ABC, Mapping):
         """
         pass
 
-    def dump_to(self, other_loader: AbstractConfigLoader, include_defaults: bool = False) -> NoReturn:
+    def dump_to(self, other_loader: AbstractConfigLoader, include_defaults: bool = False) -> None:
         """
         Dumps variables to other first_loader that been already initialized.
 
@@ -99,7 +112,9 @@ class AbstractConfigLoader(ABC, Mapping):
 
     @staticmethod
     @lru_cache(maxsize=None)
-    def key_to_path_cast(key: Union[AnyStr, Hashable, Path]) -> Union[Tuple[AnyStr, ...], Tuple[Hashable, ...]]:
+    def key_to_path_cast(
+        key: Union[AnyStr, Hashable, Path]
+    ) -> Tuple[Union[str, Hashable], ...]:
         """
         Casts a key to tuple of keys, that should be applied one by one to get to where variable lies.
         Path pointing example: config_root/database/database_ip
@@ -108,18 +123,26 @@ class AbstractConfigLoader(ABC, Mapping):
         :return: tuple of sub keys.
         """
         if isinstance(key, str) and ("/" in key):
-            return Path(key).parts
+            return tuple(Path(key).parts)
 
         if isinstance(key, Path):
-            return key.parts
+            return tuple(key.parts)
 
         return key,
 
     def get_to_variable_root(
-        self, keys: Union[Tuple[AnyStr, ...], Tuple[Hashable, ...]], lookup_at: Optional[Dict] = None
-    ) -> Dict:
+        self,
+        keys: Union[Tuple[str, ...], Tuple[Hashable, ...]],
+        lookup_at: Optional[
+            Union[
+                ChainMap[Hashable, Any],
+                MutableMapping[Hashable, Any],
+                Dict[Hashable, Any]
+            ]
+        ] = None
+    ) -> Union[ChainMap[Hashable, Any], MutableMapping[Hashable, Any], Dict[Hashable, Any]]:
         """
-        Returns an dictionary with our variable.
+        Returns a dictionary with our variable.
 
         :param keys: keys tuple we apply to get to root of variable.
         :param lookup_at: the location we're looking at. In case we need to lookup at specific part of our first_loader.
@@ -132,7 +155,7 @@ class AbstractConfigLoader(ABC, Mapping):
 
         return root
 
-    def __getitem__(self, key: Union[Hashable, AnyStr]) -> Any:
+    def __getitem__(self, key: key_type) -> Any:
         """
         Returns an item under specified key or key as path and if
         it didn't find it - raises KeyError.
@@ -145,7 +168,7 @@ class AbstractConfigLoader(ABC, Mapping):
 
         return val_root[casted_key[-1]]
 
-    def __setitem__(self, key: Union[Hashable, AnyStr], value: Any) -> NoReturn:
+    def __setitem__(self, key: key_type, value: Any) -> None:
         """
         Sets variable config_var inside of your first_loader.
 
@@ -154,13 +177,14 @@ class AbstractConfigLoader(ABC, Mapping):
         :return: nothing.
         """
 
-        casted_key = self.key_to_path_cast(key)
+        casted_key: Tuple[Union[str, Hashable], ...] = self.key_to_path_cast(key)
+        last_key = casted_key[-1]
         val_root = self.get_to_variable_root(casted_key)
 
-        if casted_key[-1] not in val_root:
+        if last_key not in val_root:
             raise KeyError(f"No key {casted_key[-1]} in {self}")
 
-        val_root[casted_key[-1]] = value
+        val_root[last_key] = value
 
     def __hash__(self):
         return hash(self.__class__.__name__ + self.__created_at)
@@ -171,6 +195,9 @@ class AbstractConfigLoader(ABC, Mapping):
     def __str__(self):
         return self.__class__.__name__
 
+    def __delitem__(self, key: key_type):
+        del self.lookup_data[key]
+
     def __len__(self) -> int:
         return len(self.lookup_data)
 
