@@ -1,31 +1,39 @@
-from collections import ChainMap
-from collections.abc import Mapping
+from __future__ import annotations
+
 from functools import partial
-from os import PathLike
 from pathlib import Path
-from typing import AnyStr, Dict, NoReturn, Union, Optional
+from typing import Dict, Optional, Union, TYPE_CHECKING
 
 import yaml
 
 from ConfigFramework.abstract.abc_loader import AbstractConfigLoader
+from ConfigFramework.custom_types import data_type, defaults_type
 
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
 
 except ImportError:
-    from yaml import Loader, Dumper
+    # Those are actually replacements for CDumper/CLoader
+    # and so there must be no problem
+    from yaml import Loader, Dumper  # type: ignore
+
+
+if TYPE_CHECKING:
+    from os import PathLike
 
 
 class YAMLLoader(AbstractConfigLoader):
     dumper = partial(yaml.dump, Dumper=Dumper)
     loader = partial(yaml.load, Loader=Loader)
 
-    def __init__(self, data: Union[Dict, ChainMap, Mapping], defaults: Dict, config_path: Path):
+    def __init__(self, data: data_type, defaults: defaults_type, config_path: Path):
         super().__init__(data, defaults)
         self.config_path = config_path
 
     @classmethod
-    def load(cls, config_path: Union[AnyStr, Path, PathLike], defaults: Optional[Dict] = None):
+    def load(  # type: ignore
+        cls, config_path: Union[str, Path, PathLike[str]], defaults: Optional[Dict] = None
+    ):
         config_path = Path(config_path)
 
         if not config_path.is_file():
@@ -34,7 +42,7 @@ class YAMLLoader(AbstractConfigLoader):
         with open(config_path, encoding='utf8') as yaml_f:
             return cls(cls.loader(yaml_f), defaults, config_path)
 
-    def dump(self, include_defaults: bool = False) -> NoReturn:
+    def dump(self, include_defaults: bool = False) -> None:
         to_dump = self.data
 
         if include_defaults:
